@@ -95,6 +95,7 @@ enum keyword_numeric_config_field {
     KBF_IKELIFETIME,
     KBF_AGGRMODE,
     KBF_MODECONFIGPULL,
+    KBF_FORCEENCAP,
     KBF_MAX         
 };
 
@@ -160,13 +161,14 @@ enum keyword_valid {
     kv_alias  = LELEM(5),     /* is an alias for another keyword */
     kv_policy = LELEM(6),     /* is a policy affecting verb, processed specially */
     kv_processed = LELEM(7),  /* is processed, do not output literal string */
+    kv_duplicateok = LELEM(8),  /* it is okay if also= items are duplicated */
 };
 #define KV_CONTEXT_MASK (kv_config|kv_conn|kv_leftright)
 
 /* values keyexchange= */
 enum keyword_keyexchange {
     KE_NONE = 0,
-    KH_IKE  = 1,
+    KE_IKE  = 1,
 };
 
 /* values for auto={add,start,route,ignore} */
@@ -206,6 +208,7 @@ enum keyword_type {
     kt_subnet,             /* an IP address subnet */
     kt_idtype,             /* an ID type */
     kt_bitstring,          /* an encryption/authentication key */
+    kt_comment,            /* a value which is a cooked comment */
 };
 
 #define NOT_ENUM NULL
